use actix_web::body::BoxBody;
use actix_web::http::StatusCode;
use actix_web::{HttpResponse, ResponseError};
use std::fmt::{Debug, Display, Formatter};

#[derive(Debug)]
pub struct FromRequestRedirect {
    url: String,
}

impl FromRequestRedirect {
    pub fn new(url: String) -> Self {
        Self { url }
    }
}

impl Display for FromRequestRedirect {
    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
        write!(f, "Redirect to {}", self.url)
    }
}

impl ResponseError for FromRequestRedirect {
    fn status_code(&self) -> StatusCode {
        StatusCode::FOUND
    }
    fn error_response(&self) -> HttpResponse<BoxBody> {
        HttpResponse::Found()
            .insert_header(("Location", self.url.as_str()))
            .body("Redirecting...")
    }
}
